From a unique_paths object that
shows all possible paths until
absorption from an initial state,
successful_transitions picks the path
that finishes in to_state, if there is one.
The initial state is the one defined in the
argument from_state
to the function unique_paths.
The process must have a tree-like structure.
successful_transitions(unique_paths_object, to_state, tmat)A vector with the unique sequence of states between two states.
An object created by running
unique_paths.
An absorbing state.
Transition matrix.
Rui Costa
This function is used by probtrans_by_convolution_clockforward and probtrans_by_convolution_clockreset.
It is not meant to be called by the user.
unique_paths;
probtrans_by_convolution_clockforward;
probtrans_by_convolution_clockreset.